@@ -503,7 +503,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
             }
 
             $promise = $this->download($package, $targetDir.'_compare', null, false);
-            $promise->then(null, function ($ex) use (&$e) {
+            $promise->then(null, static function ($ex) use (&$e) {
                 $e = $ex;
             });
             $this->httpDownloader->wait();
@@ -511,7 +511,7 @@ class FileDownloader implements DownloaderInterface, ChangeReportInterface
                 throw $e;
             }
             $promise = $this->install($package, $targetDir.'_compare', false);
-            $promise->then(null, function ($ex) use (&$e) {
+            $promise->then(null, static function ($ex) use (&$e) {
                 $e = $ex;
             });
             $this->process->wait();
