@@ -119,8 +119,11 @@ abstract class BaseIO implements IOInterface
         $githubOauth = $config->get('github-oauth');
         $gitlabOauth = $config->get('gitlab-oauth');
         $gitlabToken = $config->get('gitlab-token');
+        $forgejoToken = $config->get('forgejo-token');
         $httpBasic = $config->get('http-basic');
         $bearerToken = $config->get('bearer');
+        $customHeaders = $config->get('custom-headers');
+        $clientCertificate = $config->get('client-certificate');
 
         // reload oauth tokens from config if available
 
@@ -163,6 +166,15 @@ abstract class BaseIO implements IOInterface
             $this->checkAndSetAuthentication($domain, $username, $password);
         }
 
+        foreach ($forgejoToken as $domain => $cred) {
+            if (!in_array($domain, $config->get('forgejo-domains'), true)) {
+                $this->debug($domain.' is not in the configured forgejo-domains, adding it implicitly as authentication is configured for this domain');
+                $config->merge(['config' => ['forgejo-domains' => array_merge($config->get('forgejo-domains'), [$domain])]], 'implicit-due-to-auth');
+            }
+
+            $this->checkAndSetAuthentication($domain, $cred['username'], $cred['token']);
+        }
+
         // reload http basic credentials from config if available
         foreach ($httpBasic as $domain => $cred) {
             $this->checkAndSetAuthentication($domain, $cred['username'], $cred['password']);
@@ -172,6 +184,35 @@ abstract class BaseIO implements IOInterface
             $this->checkAndSetAuthentication($domain, $token, 'bearer');
         }
 
+        // load custom HTTP headers from config
+        foreach ($customHeaders as $domain => $headers) {
+            if ($headers !== null) {
+                $this->checkAndSetAuthentication($domain, (string) json_encode($headers), 'custom-headers');
+            }
+        }
+
+        // reload ssl client certificate credentials from config if available
+        foreach ($clientCertificate as $domain => $cred) {
+            $sslOptions = array_filter(
+                [
+                    'local_cert' => $cred['local_cert'] ?? null,
+                    'local_pk' => $cred['local_pk'] ?? null,
+                    'passphrase' => $cred['passphrase'] ?? null,
+                ],
+                static function (?string $value): bool { return $value !== null; }
+            );
+            if (!isset($sslOptions['local_cert'])) {
+                $this->writeError(
+                    sprintf(
+                        '<warning>Warning: Client certificate configuration is missing key `local_cert` for %s.</warning>',
+                        $domain
+                    )
+                );
+                continue;
+            }
+            $this->checkAndSetAuthentication($domain, 'client-certificate', (string) json_encode($sslOptions));
+        }
+
         // setup process timeout
         ProcessExecutor::setTimeout($config->get('process-timeout'));
     }
@@ -249,7 +290,7 @@ abstract class BaseIO implements IOInterface
         $message = (string) $message;
 
         if ($context !== []) {
-            $json = Silencer::call('json_encode', $context, JSON_INVALID_UTF8_IGNORE|JSON_UNESCAPED_SLASHES|JSON_UNESCAPED_UNICODE);
+            $json = Silencer::call('json_encode', $context, JSON_INVALID_UTF8_IGNORE | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
             if ($json !== false) {
                 $message .= ' ' . $json;
             }
