@@ -23,6 +23,11 @@ use Composer\EventDispatcher\EventDispatcher;
  */
 class PartialComposer
 {
+    /**
+     * @var bool
+     */
+    private $global = false;
+
     /**
      * @var RootPackageInterface
      */
@@ -34,12 +39,12 @@ class PartialComposer
     private $loop;
 
     /**
-     * @var Repository\RepositoryManager
+     * @var RepositoryManager
      */
     private $repositoryManager;
 
     /**
-     * @var Installer\InstallationManager
+     * @var InstallationManager
      */
     private $installationManager;
 
@@ -112,4 +117,14 @@ class PartialComposer
     {
         return $this->eventDispatcher;
     }
+
+    public function isGlobal(): bool
+    {
+        return $this->global;
+    }
+
+    public function setGlobal(): void
+    {
+        $this->global = true;
+    }
 }
