@@ -1,4 +1,14 @@
-<?php
+<?php declare(strict_types=1);
+
+/*
+ * This file is part of Composer.
+ *
+ * (c) Nils Adermann <naderman@naderman.de>
+ *     Jordi Boggiano <j.boggiano@seld.be>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
 
 namespace Composer\Test\Command;
 
@@ -7,7 +17,6 @@ use Composer\Test\TestCase;
 
 class AboutCommandTest extends TestCase
 {
-
     public function testAbout(): void
     {
         $composerVersion = Composer::getVersion();
