@@ -12,22 +12,16 @@
 
 namespace Composer\Test\Downloader;
 
-use Composer\Autoload\AutoloadGenerator;
 use Composer\Downloader\FileDownloader;
 use Composer\EventDispatcher\EventDispatcher;
-use Composer\IO\NullIO;
 use Composer\Plugin\PluginEvents;
 use Composer\Plugin\PreFileDownloadEvent;
-use Composer\Repository\InstalledArrayRepository;
-use Composer\Repository\RepositoryManager;
-use Composer\Test\Mock\HttpDownloaderMock;
-use Composer\Test\Mock\InstallationManagerMock;
 use Composer\Test\TestCase;
 use Composer\Util\Filesystem;
 use Composer\Util\Http\Response;
 use Composer\Util\Loop;
 use Composer\Config;
-use Composer\Composer;
+use Composer\PartialComposer;
 
 class FileDownloaderTest extends TestCase
 {
@@ -156,12 +150,9 @@ class FileDownloaderTest extends TestCase
             'bin-dir' => $path.'/vendor/bin',
         ]);
 
-        $composer = new Composer;
+        $composer = new PartialComposer;
         $composer->setPackage($rootPackage);
         $composer->setConfig($config);
-        $composer->setRepositoryManager($rm = new RepositoryManager(new NullIO(), $config, new HttpDownloaderMock()));
-        $rm->setLocalRepository(new InstalledArrayRepository([]));
-        $composer->setInstallationManager(new InstallationManagerMock());
 
         $expectedUrl = 'foobar';
         $expectedCacheKey = 'dummy/pkg/'.hash('sha1', $expectedUrl).'.';
@@ -174,7 +165,6 @@ class FileDownloaderTest extends TestCase
         $dispatcher->addListener(PluginEvents::PRE_FILE_DOWNLOAD, static function (PreFileDownloadEvent $event) use ($expectedUrl): void {
             $event->setProcessedUrl($expectedUrl);
         });
-        $composer->setAutoloadGenerator(new AutoloadGenerator($dispatcher));
 
         $cacheMock = $this->getMockBuilder('Composer\Cache')
             ->disableOriginalConstructor()
@@ -243,12 +233,9 @@ class FileDownloaderTest extends TestCase
             'bin-dir' => $path.'/vendor/bin',
         ]);
 
-        $composer = new Composer;
+        $composer = new PartialComposer;
         $composer->setPackage($rootPackage);
         $composer->setConfig($config);
-        $composer->setRepositoryManager($rm = new RepositoryManager(new NullIO(), $config, new HttpDownloaderMock()));
-        $rm->setLocalRepository(new InstalledArrayRepository([]));
-        $composer->setInstallationManager(new InstallationManagerMock());
 
         $expectedUrl = 'url';
         $customCacheKey = 'xyzzy';
@@ -262,7 +249,6 @@ class FileDownloaderTest extends TestCase
         $dispatcher->addListener(PluginEvents::PRE_FILE_DOWNLOAD, static function (PreFileDownloadEvent $event) use ($customCacheKey): void {
             $event->setCustomCacheKey($customCacheKey);
         });
-        $composer->setAutoloadGenerator(new AutoloadGenerator($dispatcher));
 
         $cacheMock = $this->getMockBuilder('Composer\Cache')
             ->disableOriginalConstructor()
